summaryrefslogtreecommitdiffstats
path: root/klettres
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /klettres
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'klettres')
-rw-r--r--klettres/klettres/fontsdlg.ui6
-rw-r--r--klettres/klettres/klettres.cpp88
-rw-r--r--klettres/klettres/klettres.h5
-rw-r--r--klettres/klettres/klettresview.cpp12
-rw-r--r--klettres/klettres/klettresview.h5
-rw-r--r--klettres/klettres/klnewstuff.cpp4
-rw-r--r--klettres/klettres/prefs_addons.h6
-rw-r--r--klettres/klettres/soundfactory.cpp10
-rw-r--r--klettres/klettres/soundfactory.h7
-rw-r--r--klettres/klettres/timer.h1
-rw-r--r--klettres/klettres/timerdlg.ui32
11 files changed, 90 insertions, 86 deletions
diff --git a/klettres/klettres/fontsdlg.ui b/klettres/klettres/fontsdlg.ui
index 34c72ad5..f5fb605f 100644
--- a/klettres/klettres/fontsdlg.ui
+++ b/klettres/klettres/fontsdlg.ui
@@ -1,10 +1,10 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
<class>fontsdlg</class>
-<widget class="QDialog">
+<widget class="TQDialog">
<property name="name">
<cstring>fontsdlg</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>0</x>
<y>0</y>
@@ -31,7 +31,7 @@
</widget>
<customwidgets>
</customwidgets>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kfontdialog.h</includehint>
</includehints>
diff --git a/klettres/klettres/klettres.cpp b/klettres/klettres/klettres.cpp
index 4d378ee6..cbd4c165 100644
--- a/klettres/klettres/klettres.cpp
+++ b/klettres/klettres/klettres.cpp
@@ -18,7 +18,7 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-//Qt includes
+//TQt includes
#include <tqbitmap.h>
#include <tqdir.h>
#include <tqfile.h>
@@ -93,12 +93,12 @@ void KLettres::findLanguages()
for (TQStringList::Iterator it =mdirs.begin(); it !=mdirs.end(); ++it ) {
TQDir dir(*it);
m_languages += dir.entryList(TQDir::Dirs, TQDir::Name);
- m_languages.remove(m_languages.find("."));
- m_languages.remove(m_languages.find(".."));
+ m_languages.remove(m_languages.tqfind("."));
+ m_languages.remove(m_languages.tqfind(".."));
}
- m_languages.remove(m_languages.find("pics"));
- m_languages.remove(m_languages.find("data"));
- m_languages.remove(m_languages.find("icons"));
+ m_languages.remove(m_languages.tqfind("pics"));
+ m_languages.remove(m_languages.tqfind("data"));
+ m_languages.remove(m_languages.tqfind("icons"));
m_languages.sort();
if (m_languages.isEmpty()) return;
Prefs::setLanguages(m_languages);
@@ -107,7 +107,7 @@ void KLettres::findLanguages()
TQStringList temp_languages;
for (uint i=0; i<m_languages.count(); i++)
{
- if (m_languages.contains(m_languages[i])>1) {
+ if (m_languages.tqcontains(m_languages[i])>1) {
temp_languages.append(m_languages[i]);
m_languages.remove(m_languages[i]);
}
@@ -122,12 +122,12 @@ void KLettres::findLanguages()
m_languages.sort();
//write the present languages in config so they cannot be downloaded
KConfig *config=kapp->config();
- config->setGroup("KNewStuffStatus");
+ config->setGroup("KNewStufftqStatus");
for (uint i=0; i<m_languages.count(); i++)
{
TQString tmp = m_languages[i];
if (!config->readEntry(tmp))
- config->writeEntry(tmp, TQDate::currentDate().toString());
+ config->writeEntry(tmp, TQString(TQDate::tqcurrentDate().toString()));
}
//we look in $KDEDIR/share/locale/all_languages from /kdelibs/kdecore/all_languages
//to find the name of the country
@@ -155,23 +155,23 @@ TQString Prefs::defaultLanguage()
TQStringList defaultLanguages = KGlobal::locale()->languagesTwoAlpha();
if (!defaultLanguages.isEmpty()) {
//scan to see if defaultLanguages[0] belongs to m_languages. If not, en is default.
- int i = Prefs::self()->m_languages.findIndex(defaultLanguages[0]);
- if (Prefs::self()->m_languages.contains(Prefs::language()))
+ int i = Prefs::self()->m_languages.tqfindIndex(defaultLanguages[0]);
+ if (Prefs::self()->m_languages.tqcontains(Prefs::language()))
return Prefs::language(); //the last language played
else if (i<1)
return "en"; //if no other
else
return Prefs::self()->m_languages[i]; //KDE default if exists
}
- return TQString::null;
+ return TQString();
}
-bool KLettres::loadLayout(TQDomDocument &layoutDocument)
+bool KLettres::loadLayout(TQDomDocument &tqlayoutDocument)
{
- TQFile layoutFile(locate("data", "klettres/"+Prefs::language()+"/sounds.xml"));
+ TQFile tqlayoutFile(locate("data", "klettres/"+Prefs::language()+"/sounds.xml"));
//if xml file is not found, program exits
- if (!layoutFile.exists())
+ if (!tqlayoutFile.exists())
{
kdWarning() << "sounds.xml file not found in $KDEDIR/share/apps/klettres/"+Prefs::language() << endl;
TQString mString=i18n("The file sounds.xml was not found in\n"
@@ -180,31 +180,31 @@ bool KLettres::loadLayout(TQDomDocument &layoutDocument)
KMessageBox::information( this, mString,"KLettres - Error" );
kapp->quit();//exit(1);
}
- if (!layoutFile.open(IO_ReadOnly))
+ if (!tqlayoutFile.open(IO_ReadOnly))
return false;
//Check if document is well-formed
- if (!layoutDocument.setContent(&layoutFile))
+ if (!tqlayoutDocument.setContent(&tqlayoutFile))
{
- layoutFile.close();
+ tqlayoutFile.close();
return false;
}
- layoutFile.close();
+ tqlayoutFile.close();
return true;
}
void KLettres::setupActions()
{
- KAction *m_newAction = new KAction(i18n("New Sound"), "file_new", CTRL+Key_N, m_view, TQT_SLOT(game()), actionCollection(), "play_new");
+ KAction *m_newAction = new KAction(i18n("New Sound"), "file_new", CTRL+Key_N, TQT_TQOBJECT(m_view), TQT_SLOT(game()), actionCollection(), "play_new");
m_newAction->setToolTip(i18n("Play a new sound"));
m_newAction->setWhatsThis(i18n("You can play a new sound by clicking this button or using the File menu, New Sound."));
- new KAction( i18n("Get Alphabet in New Language..."), "knewstuff", 0, this, TQT_SLOT( slotDownloadNewStuff() ), actionCollection(), "downloadnewstuff" );
- KAction *m_playAgainAction = new KAction(i18n("Replay Sound"),"player_play", CTRL+Key_P, m_view, TQT_SLOT(slotPlayAgain()), actionCollection(), "play_again");
+ new KAction( i18n("Get Alphabet in New Language..."), "knewstuff", 0, TQT_TQOBJECT(this), TQT_SLOT( slotDownloadNewStuff() ), actionCollection(), "downloadnewstuff" );
+ KAction *m_playAgainAction = new KAction(i18n("Replay Sound"),"player_play", CTRL+Key_P, TQT_TQOBJECT(m_view), TQT_SLOT(slotPlayAgain()), actionCollection(), "play_again");
m_playAgainAction->setToolTip(i18n("Play the same sound again"));
m_playAgainAction->setWhatsThis(i18n("You can replay the same sound again by clicking this button or using the File menu, Replay Sound."));
- KStdAction::quit(kapp, TQT_SLOT(quit()), actionCollection());
+ KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT(quit()), actionCollection());
- m_menubarAction = new KToggleAction(i18n("Show &Menubar"),"editclear", CTRL+Key_M, this, TQT_SLOT(slotMenubar()), actionCollection(), "menubar");
+ m_menubarAction = new KToggleAction(i18n("Show &Menubar"),"editclear", CTRL+Key_M, TQT_TQOBJECT(this), TQT_SLOT(slotMenubar()), actionCollection(), "menubar");
m_menubarAction->setCheckedState(i18n("Hide &Menubar"));
m_menubarAction->setChecked(true);
m_menubarAction->setWhatsThis(i18n("You can show or hide the menubar as you wish by clicking this button."));
@@ -230,16 +230,16 @@ void KLettres::setupActions()
m_themeAction->setToolTip(i18n("Select the theme"));
m_themeAction->setWhatsThis(i18n("Here you can change the theme for KLettres. A theme consists in the background picture and the font color for the letter displayed."));
- m_kidAction = new KToggleAction(i18n("Mode Kid"), "klettres_kids", CTRL+Key_K, this, TQT_SLOT(slotModeKid()), actionCollection(), "mode_kid");
+ m_kidAction = new KToggleAction(i18n("Mode Kid"), "klettres_kids", CTRL+Key_K, TQT_TQOBJECT(this), TQT_SLOT(slotModeKid()), actionCollection(), "mode_kid");
m_kidAction->setWhatsThis(i18n("If you are in the Grown-up mode, clicking on this button will set up the Kid mode. The Kid mode has no menubar and the font is bigger in the statusbar."));
- m_grownupAction = new KToggleAction(i18n("Mode Grown-up"), "klettres_grownup", CTRL+Key_G, this, TQT_SLOT(slotModeGrownup()), actionCollection(), "mode_grownup");
+ m_grownupAction = new KToggleAction(i18n("Mode Grown-up"), "klettres_grownup", CTRL+Key_G, TQT_TQOBJECT(this), TQT_SLOT(slotModeGrownup()), actionCollection(), "mode_grownup");
m_grownupAction->setWhatsThis(i18n("The Grown-up mode is the normal mode where you can see the menubar."));
connect(m_levelAction, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotChangeLevel(int)));
connect(m_languageAction, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotChangeLanguage(int)));
connect(m_themeAction, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotChangeTheme(int)));
- KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
+ KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsPreferences()), actionCollection());
setupGUI();
}
@@ -284,12 +284,12 @@ void KLettres::loadSettings()
//m_view->selectedLanguage = selectedLanguage;
m_languageAction->setCurrentItem(Prefs::languageNumber());
TQString langString = m_languageNames[Prefs::languageNumber()];
- langString.replace("&", TQString::null);
- m_langLabel->setText(i18n("Current language is %1").arg(langString));
+ langString.tqreplace("&", TQString());
+ m_langLabel->setText(i18n("Current language is %1").tqarg(langString));
loadLangToolBar();
// load default level
m_levelAction->setCurrentItem(Prefs::level()-1);
- m_levLabel->setText(i18n("Current level is %1").arg(Prefs::level()));
+ m_levLabel->setText(i18n("Current level is %1").tqarg(Prefs::level()));
if (Prefs::theme() == Prefs::EnumTheme::classroom) {
m_themeAction->setCurrentItem(0);
@@ -358,7 +358,7 @@ void KLettres::updateLevMenu(int id)
{
//m_levelCombo->setCurrentItem(id);
m_levelAction->setCurrentItem(id);
- m_levLabel->setText(i18n("Current level is %1").arg(Prefs::level()));
+ m_levLabel->setText(i18n("Current level is %1").tqarg(Prefs::level()));
}
void KLettres::slotChangeLanguage(int newLanguage)
@@ -368,8 +368,8 @@ void KLettres::slotChangeLanguage(int newLanguage)
Prefs::writeConfig();
// Update the StatusBar
TQString langString = m_languageNames[newLanguage];
- langString.replace("&", TQString::null);
- m_langLabel->setText(i18n("Current language is %1").arg(langString));
+ langString.tqreplace("&", TQString());
+ m_langLabel->setText(i18n("Current language is %1").tqarg(langString));
loadLangToolBar();
// Change language effectively
bool ok = loadLayout(soundFactory->m_layoutsDocument);
@@ -452,14 +452,14 @@ void KLettres::loadLangToolBar()
if (m_languages[Prefs::languageNumber()]== "cs" || m_languages[Prefs::languageNumber()]== "da" || m_languages[Prefs::languageNumber()]== "sk" || m_languages[Prefs::languageNumber()]== "es" || m_languages[Prefs::languageNumber()]== "de" || m_languages[Prefs::languageNumber()]== "nds")//Dutch, English, French and Italian have no special characters
{
allData.clear();
- TQString myString=TQString("klettres/%1.txt").arg(m_languages[Prefs::languageNumber()]);
+ TQString myString=TQString("klettres/%1.txt").tqarg(m_languages[Prefs::languageNumber()]);
TQFile myFile;
myFile.setName(locate("data",myString));
if (!myFile.exists())
{
TQString mString=i18n("File $KDEDIR/share/apps/klettres/%1.txt not found;\n"
- "please check your installation.").arg(m_languages[Prefs::languageNumber()]);
+ "please check your installation.").tqarg(m_languages[Prefs::languageNumber()]);
KMessageBox::sorry( this, mString,
i18n("Error") );
kapp->quit();
@@ -475,7 +475,7 @@ void KLettres::loadLangToolBar()
openFileStream.close();
for (int i=0; i<(int) allData.count(); i++) {
if (!allData[i].isEmpty())
- m_secondToolbar->insertButton (charIcon(allData[i].at(0)), i, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotPasteChar()), true, i18n("Inserts the character %1").arg(allData[i]), i+1 );
+ m_secondToolbar->insertButton (charIcon(allData[i].at(0)), i, TQT_SIGNAL( clicked() ), TQT_TQOBJECT(this), TQT_SLOT( slotPasteChar()), true, i18n("Inserts the character %1").tqarg(allData[i]), i+1 );
}
}
}
@@ -489,7 +489,7 @@ void KLettres::slotPasteChar()
TQString KLettres::charIcon(const TQChar & c)
{
///Create a name and path for the icon
- TQString s = locateLocal("icon", "char" + TQString::number(c.unicode()) + ".png");
+ TQString s = locateLocal("icon", "char" + TQString::number(c.tqunicode()) + ".png");
TQRect r(4, 4, 120, 120);
@@ -501,19 +501,19 @@ TQString KLettres::charIcon(const TQChar & c)
///Create the pixmap
TQPixmap pm(128, 128);
- pm.fill(Qt::white);
+ pm.fill(TQt::white);
TQPainter p(&pm);
p.setFont(font);
- p.setPen(Qt::black);
- p.drawText(r, Qt::AlignCenter, (TQString) c);
+ p.setPen(TQt::black);
+ p.drawText(r, TQt::AlignCenter, (TQString) c);
- ///Create transparency mask
+ ///Create transparency tqmask
TQBitmap bm(128, 128);
- bm.fill(Qt::color0);
+ bm.fill(TQt::color0);
TQPainter b(&bm);
b.setFont(font);
- b.setPen(Qt::color1);
- b.drawText(r, Qt::AlignCenter, (TQString) c);
+ b.setPen(TQt::color1);
+ b.drawText(r, TQt::AlignCenter, (TQString) c);
///Mask the pixmap
pm.setMask(bm);
diff --git a/klettres/klettres/klettresview.cpp b/klettres/klettres/klettresview.cpp
index c9891bf1..6417d978 100644
--- a/klettres/klettres/klettresview.cpp
+++ b/klettres/klettres/klettresview.cpp
@@ -33,10 +33,10 @@
#include "klettresview.h"
#include "prefs.h"
-KLettresView::KLettresView(KLettres *parent)
- : TQWidget(parent)
+KLettresView::KLettresView(KLettres *tqparent)
+ : TQWidget(tqparent)
{
- m_klettres = parent;
+ m_klettres = tqparent;
setMinimumSize( TQSize( 640, 480 ) );
setMaximumSize( TQSize( 640, 480 ) );
@@ -107,12 +107,12 @@ void KLettresView::paintEvent( TQPaintEvent * )
//m_letterEdit->setPaletteForegroundColor(TQColor(115, 50, 95));
}
else if (Prefs::theme() == Prefs::EnumTheme::arctic) {
- paint.setPen( Qt::white );
+ paint.setPen( TQt::white );
//m_letterEdit->setPaletteForegroundColor(TQColor(48, 75, 137));
}
else {
- paint.setPen( Qt::white );
- //m_letterEdit->setPaletteForegroundColor(Qt::black);
+ paint.setPen( TQt::white );
+ //m_letterEdit->setPaletteForegroundColor(TQt::black);
}
paint.drawText(50, 230, m_currentLetter);
}
diff --git a/klettres/klettres/klettresview.h b/klettres/klettres/klettresview.h
index c27b94e5..00bf2364 100644
--- a/klettres/klettres/klettresview.h
+++ b/klettres/klettres/klettresview.h
@@ -38,14 +38,15 @@ class KLettres;
*/
-class KLettresView : public QWidget
+class KLettresView : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default constructor
*/
- KLettresView(KLettres *parent);
+ KLettresView(KLettres *tqparent);
/**
* Destructor
diff --git a/klettres/klettres/klnewstuff.cpp b/klettres/klettres/klnewstuff.cpp
index ed6061ba..3741bb5f 100644
--- a/klettres/klettres/klnewstuff.cpp
+++ b/klettres/klettres/klnewstuff.cpp
@@ -49,8 +49,8 @@ bool KLNewStuff::install( const TQString &fileName )
//refresh Languages menu
//kdDebug() << "---- selected language : " << m_view->m_klettres->selectedLanguage << endl;
m_view->m_klettres->m_languageAction->setItems(m_view->m_klettres->m_languageNames);
- m_view->m_klettres->slotChangeLanguage(m_view->m_klettres->m_languages.findIndex(Prefs::defaultLanguage()));
- m_view->m_klettres->m_languageAction->setCurrentItem(m_view->m_klettres->m_languages.findIndex(Prefs::defaultLanguage()));
+ m_view->m_klettres->slotChangeLanguage(m_view->m_klettres->m_languages.tqfindIndex(Prefs::defaultLanguage()));
+ m_view->m_klettres->m_languageAction->setCurrentItem(m_view->m_klettres->m_languages.tqfindIndex(Prefs::defaultLanguage()));
return true;
}
diff --git a/klettres/klettres/prefs_addons.h b/klettres/klettres/prefs_addons.h
index ec28026a..1e02b2e3 100644
--- a/klettres/klettres/prefs_addons.h
+++ b/klettres/klettres/prefs_addons.h
@@ -33,13 +33,13 @@ static void setLanguageNumber(int i)
static int languageNumber()
{
- int i = Prefs::self()->m_languages.findIndex(language());
+ int i = Prefs::self()->m_languages.tqfindIndex(language());
if (i != -1)
return i;
- i = Prefs::self()->m_languages.findIndex(defaultLanguage());
+ i = Prefs::self()->m_languages.tqfindIndex(defaultLanguage());
if (i != -1)
return i;
- i = Prefs::self()->m_languages.findIndex("en");
+ i = Prefs::self()->m_languages.tqfindIndex("en");
if (i != -1)
return i;
diff --git a/klettres/klettres/soundfactory.cpp b/klettres/klettres/soundfactory.cpp
index e23bc501..6a2a0ebf 100644
--- a/klettres/klettres/soundfactory.cpp
+++ b/klettres/klettres/soundfactory.cpp
@@ -33,10 +33,10 @@
#include "prefs.h"
-SoundFactory::SoundFactory(KLettres *parent, const char *name)
- : TQObject(parent, name)
+SoundFactory::SoundFactory(KLettres *tqparent, const char *name)
+ : TQObject(tqparent, name)
{
- klettres = parent;
+ klettres = tqparent;
namesList = filesList = 0;
sounds = 0;
@@ -78,7 +78,7 @@ void SoundFactory::loadFailure()
KMessageBox::error(klettres, i18n("Error while loading the sound names."));
}
-bool SoundFactory::loadLanguage(TQDomDocument &layoutDocument, TQString currentLanguage)
+bool SoundFactory::loadLanguage(TQDomDocument &tqlayoutDocument, TQString currentLanguage)
{
TQDomNodeList languagesList,
alphabetList,
@@ -90,7 +90,7 @@ bool SoundFactory::loadLanguage(TQDomDocument &layoutDocument, TQString currentL
soundNameElement;
TQDomAttr nameAttribute, fileAttribute;
- languagesList = layoutDocument.elementsByTagName("language");
+ languagesList = tqlayoutDocument.elementsByTagName("language");
TQDomAttr codeAttribute;
//check if the sound files match current language
languageElement = (const TQDomElement &) languagesList.item(0).toElement();
diff --git a/klettres/klettres/soundfactory.h b/klettres/klettres/soundfactory.h
index 2cc8a5de..e6105db7 100644
--- a/klettres/klettres/soundfactory.h
+++ b/klettres/klettres/soundfactory.h
@@ -38,13 +38,14 @@ class KLettres;
* @version 1.1
*/
-class SoundFactory : public QObject
+class SoundFactory : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- SoundFactory(KLettres *parent, const char *name);
+ SoundFactory(KLettres *tqparent, const char *name);
~SoundFactory();
///Call the main instance of the program
@@ -64,7 +65,7 @@ public:
* Call that when you read the language from Config and when the language changes
* or when the level changes
*/
- bool loadLanguage(TQDomDocument &layoutDocument, TQString currentLanguage);
+ bool loadLanguage(TQDomDocument &tqlayoutDocument, TQString currentLanguage);
///The language document
TQDomDocument m_layoutsDocument;
diff --git a/klettres/klettres/timer.h b/klettres/klettres/timer.h
index 28634cf3..418992d4 100644
--- a/klettres/klettres/timer.h
+++ b/klettres/klettres/timer.h
@@ -35,6 +35,7 @@
class Timer : public timerdlg
{
Q_OBJECT
+ TQ_OBJECT
public:
///Constructor
diff --git a/klettres/klettres/timerdlg.ui b/klettres/klettres/timerdlg.ui
index 91ab486f..bf971181 100644
--- a/klettres/klettres/timerdlg.ui
+++ b/klettres/klettres/timerdlg.ui
@@ -1,10 +1,10 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
<class>timerdlg</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>timerdlg</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>0</x>
<y>0</y>
@@ -12,7 +12,7 @@
<height>260</height>
</rect>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>350</width>
<height>0</height>
@@ -30,7 +30,7 @@
<string>Set the time between 2 letters.</string>
</property>
</widget>
- <widget class="QSlider" row="2" column="0" rowspan="1" colspan="4">
+ <widget class="TQSlider" row="2" column="0" rowspan="1" colspan="4">
<property name="name">
<cstring>kcfg_KidTimer</cstring>
</property>
@@ -62,7 +62,7 @@
<string>Only used if Use a timer is checked</string>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>textLabel1</cstring>
</property>
@@ -80,7 +80,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>264</width>
<height>20</height>
@@ -97,7 +97,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>25</width>
<height>16</height>
@@ -114,14 +114,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>270</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QSlider" row="6" column="0" rowspan="1" colspan="4">
+ <widget class="TQSlider" row="6" column="0" rowspan="1" colspan="4">
<property name="name">
<cstring>kcfg_GrownTimer</cstring>
</property>
@@ -163,14 +163,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>228</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QLabel" row="5" column="0" rowspan="1" colspan="2">
+ <widget class="TQLabel" row="5" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>textLabel1_2</cstring>
</property>
@@ -178,7 +178,7 @@
<string>Grown-up Mode</string>
</property>
</widget>
- <widget class="QLabel" row="7" column="3">
+ <widget class="TQLabel" row="7" column="3">
<property name="name">
<cstring>timeGrownLabel</cstring>
</property>
@@ -199,7 +199,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>226</width>
<height>20</height>
@@ -216,14 +216,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>25</width>
<height>16</height>
</size>
</property>
</spacer>
- <widget class="QLabel" row="3" column="3">
+ <widget class="TQLabel" row="3" column="3">
<property name="name">
<cstring>timeKidLabel</cstring>
</property>
@@ -238,7 +238,7 @@
</widget>
<customwidgets>
</customwidgets>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kactivelabel.h</includehint>
</includehints>
diff --git a/klettres/klettres/klettres.h b/klettres/klettres/klettres.h
index afed715c..cff0d88c 100644
--- a/klettres/klettres/klettres.h
+++ b/klettres/klettres/klettres.h
@@ -46,6 +46,7 @@ class KLNewStuff;
class KLettres : public KMainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
///Constructor
@@ -61,10 +62,10 @@ public:
TQStringList m_languageNames;
/**
*Load the xml file
*@param layoutDocument the xml file
*@return bool true if the xml document is found and well formed, false otherwise
*/
- bool loadLayout(TQDomDocument &layoutDocument);
+ bool loadLayout(TQDomDocument &tqlayoutDocument);
///Number corresponding to the selected language: 0 is Czech, 1 is Danish, 2 is English (default), 3 is French, 4 is Dutch, 5 is Slovak
//uint selectedLanguage;
///Action that sets up the Language menu
@@ -61,10 +62,10 @@ public:
/**
*Load the xml file
- *@param layoutDocument the xml file
+ *@param tqlayoutDocument the xml file
*@return bool true if the xml document is found and well formed, false otherwise
*/